#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deque
version:              0.4.4.2
visibility:           public
id:                   deque-0.4.4.2-13Epkjeh4MwAr1QCtZ8Wec
key:                  deque-0.4.4.2-13Epkjeh4MwAr1QCtZ8Wec
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/deque
synopsis:             Double-ended queues
description:
    Strict and lazy implementations of Double-Ended Queue (aka Dequeue or Deque)
    based on head-tail linked list.

category:             Data
abi:                  e62a9914f5c339439fbc3bcc8e1688fe
exposed:              True
exposed-modules:
    Deque.Lazy Deque.Lazy.Reader Deque.Lazy.State Deque.Strict
    Deque.Strict.Reader Deque.Strict.State

hidden-modules:       Deque.Lazy.Defs Deque.Prelude Deque.Strict.Defs
import-dirs:          /usr/lib/ghc-9.6.6/site-local/deque-0.4.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/deque-0.4.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/deque-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deque
hs-libraries:         HSdeque-0.4.4.2-13Epkjeh4MwAr1QCtZ8Wec
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-H6imxCsecEO4wNDTcxh8s7 mtl-2.3.1
    strict-list-0.1.7.6-GpBBYx7ra314x8yWgsS6f8

haddock-interfaces:   /usr/share/doc/haskell-deque/html/deque.haddock
haddock-html:         /usr/share/doc/haskell-deque/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

